# Table of Contents

- [reports-for-ai-agents](<./reports-for-ai-agents.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Reports for AI Agents](<./Reports-for-AI-Agents.md>)
  - [Overview](<./Reports-for-AI-Agents/Overview.md>)
  - [Prerequisites](<./Reports-for-AI-Agents/Prerequisites.md>)
  - [Available Reports](<./Reports-for-AI-Agents/Available-Reports.md>)
